django\_opt\_out.plugins.sparkpost package
==========================================

Submodules
----------

django\_opt\_out.plugins.sparkpost.apps module
----------------------------------------------

.. automodule:: django_opt_out.plugins.sparkpost.apps
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out.plugins.sparkpost.hooks module
-----------------------------------------------

.. automodule:: django_opt_out.plugins.sparkpost.hooks
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out.plugins.sparkpost.signals module
-------------------------------------------------

.. automodule:: django_opt_out.plugins.sparkpost.signals
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out.plugins.sparkpost.urls module
----------------------------------------------

.. automodule:: django_opt_out.plugins.sparkpost.urls
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out.plugins.sparkpost.views module
-----------------------------------------------

.. automodule:: django_opt_out.plugins.sparkpost.views
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: django_opt_out.plugins.sparkpost
    :members:
    :undoc-members:
    :show-inheritance:
